Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrTransactionsTooManyOperations = errors.New("the transaction contains more operations than supported by the state store")
Functions ¶
This section is empty.
Types ¶
type Backend ¶
type Backend interface {
contribstate.Store
contribstate.TransactionalStore
}
type Interface ¶
type Interface interface {
// Get retrieves actor state.
Get(ctx context.Context, req *api.GetStateRequest) (*api.StateResponse, error)
// GetBulk retrieves actor state in bulk.
GetBulk(ctx context.Context, req *api.GetBulkStateRequest) (api.BulkStateResponse, error)
// TransactionalStateOperation performs a transactional state operation with the actor state store.
TransactionalStateOperation(ctx context.Context, ignoreHosted bool, req *api.TransactionalRequest) error
}
Click to show internal directories.
Click to hide internal directories.