clients

package
v1.16.0-rc.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2025 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Clients

type Clients struct {
	// contains filtered or unexported fields
}

Clients builds Scheduler clients and provides those clients in a round-robin fashion.

func New

func New(opts Options) *Clients

func (*Clients) Addresses added in v1.15.6

func (c *Clients) Addresses() []string

func (*Clients) Disable added in v1.15.6

func (c *Clients) Disable()

func (*Clients) Next

Next returns the next client in a round-robin manner.

func (*Clients) Reload added in v1.15.6

func (c *Clients) Reload(ctx context.Context, addresses []string) error

type Options

type Options struct {
	Security security.Handler
}

Options contains the configuration options for the Scheduler clients.

Directories

Path Synopsis

Jump to